@@ -9,6 +9,7 @@
 #' @param ee A list of values representing employees (e.g. employee IDs).
 #' @param supv A list of values representing the supervisors of the employees. These values should be
 #' of the same type as the employee values.
+#' @param printTree Logical indicator to print the calculated data tree to the console.
 #' @import data.tree
 #' @export
 #' @return data frame
@@ -17,7 +18,7 @@
 #' supv = c("Julie","Julie","Susan","George")
 #' hierarchyWide(ee,supv)
 
-hierarchyWide = function(ee,supv){
+hierarchyWide = function(ee,supv,printTree=TRUE){
 
   if(is.factor(ee)) ee = as.character(ee)
   if(is.factor(supv)) supv = as.character(supv)
@@ -28,8 +29,11 @@ hierarchyWide = function(ee,supv){
   }else{
     df = data.frame(ee,supv,stringsAsFactors=F)
     tree = FromDataFrameNetwork(df)
-    print("The hierarchy structure:")
-    lev = max(print(tree,by="level")[,2])
+    lev = max(tree$Get("level"))
+    if(printTree==T){
+      print("The hierarchy structure:")
+      print(tree,"level")
+    }
     if(lev>2){
       for(i in 3:lev){
         df[,i] = ""
@@ -44,7 +48,7 @@ hierarchyWide = function(ee,supv){
     df.new = t(apply(df,1,function(x){c(x[is.na(x)],x[!is.na(x)])}))
     df.new = as.data.frame(cbind(df$ee,df.new),stringsAsFactors=F)
     for(i in 2:ncol(df.new)){
-      df.new[,i] = ifelse(df.new[,i]==df.new[1],NA,df.new[,i])
+      df.new[,i] = ifelse(df.new[,i]==df.new[,1],NA,df.new[,i])
     }
     df.new = df.new[colSums(!is.na(df.new)) > 0]
     df.new = cbind(df.new[1],rev(df.new[2:ncol(df.new)]))
